@@ -7,7 +7,15 @@
 #pragma once
 
 #include <glib-object.h>
+#ifdef HAVE_GUSB
 #include <gusb.h>
+#else
+#ifndef __GI_SCANNER__
+typedef GObject GUsbContext;
+typedef GObject GUsbDevice;
+#define G_USB_CHECK_VERSION(a,c,b)	0
+#endif
+#endif
 
 #include "fu-plugin.h"
 #include "fu-udev-device.h"
@@ -18,13 +26,7 @@ G_DECLARE_DERIVABLE_TYPE (FuUsbDevice, fu_usb_device, FU, USB_DEVICE, FuDevice)
 struct _FuUsbDeviceClass
 {
 	FuDeviceClass	parent_class;
-	gboolean	 (*open)		(FuUsbDevice		*device,
-						 GError			**error);
-	gboolean	 (*close)		(FuUsbDevice		*device,
-						 GError			**error);
-	gboolean	 (*probe)		(FuUsbDevice		*device,
-						 GError			**error);
-	gpointer	__reserved[28];
+	gpointer	__reserved[31];
 };
 
 FuUsbDevice	*fu_usb_device_new			(GUsbDevice	*usb_device);
